@@ -40,18 +40,18 @@
 #define SCALE_SIZE 128
 
 static const char *output_icon_names[] = {
-        "audio-volume-muted",
-        "audio-volume-low",
-        "audio-volume-medium",
-        "audio-volume-high",
+        "audio-volume-muted-symbolic",
+        "audio-volume-low-symbolic",
+        "audio-volume-medium-symbolic",
+        "audio-volume-high-symbolic",
         NULL
 };
 
 static const char *input_icon_names[] = {
-        "audio-input-microphone-muted",
-        "audio-input-microphone-low",
-        "audio-input-microphone-medium",
-        "audio-input-microphone-high",
+        "audio-input-microphone-muted-symbolic",
+        "audio-input-microphone-low-symbolic",
+        "audio-input-microphone-medium-symbolic",
+        "audio-input-microphone-high-symbolic",
         NULL
 };
 
@@ -73,7 +73,7 @@ maybe_show_status_icons (GvcApplet *applet)
 {
         gboolean        show;
         GvcMixerStream *stream;
-        GSList         *source_outputs;
+        GSList         *source_outputs, *l;
 
         show = TRUE;
         stream = gvc_mixer_control_get_default_sink (applet->priv->control);
@@ -87,7 +87,24 @@ maybe_show_status_icons (GvcApplet *applet)
         stream = gvc_mixer_control_get_default_source (applet->priv->control);
         source_outputs = gvc_mixer_control_get_source_outputs (applet->priv->control);
         if (stream != NULL && source_outputs != NULL) {
-                show = TRUE;
+                /* Check that we're not trying to add the peak detector
+                 * as an application doing recording */
+                for (l = source_outputs ; l ; l = l->next) {
+                        GvcMixerStream *s = l->data;
+                        const char *id;
+
+                        id = gvc_mixer_stream_get_application_id (s);
+                        if (id == NULL) {
+                                show = TRUE;
+                                break;
+                        }
+
+                        if (!g_str_equal (id, "org.gnome.VolumeControl") &&
+                            !g_str_equal (id, "org.PulseAudio.pavucontrol")) {
+                                show = TRUE;
+                                break;
+                        }
+                }
         }
         gtk_status_icon_set_visible (GTK_STATUS_ICON (applet->priv->input_status_icon), show);
 
@@ -124,8 +141,9 @@ update_default_source (GvcApplet *applet)
         if (stream != NULL) {
                 gvc_stream_status_icon_set_mixer_stream (applet->priv->input_status_icon,
                                                          stream);
+                maybe_show_status_icons(applet);
         } else {
-                g_warning ("Unable to get default source");
+                g_debug ("Unable to get default source, or no source available");
         }
 }
 
@@ -138,6 +156,7 @@ update_default_sink (GvcApplet *applet)
         if (stream != NULL) {
                 gvc_stream_status_icon_set_mixer_stream (applet->priv->output_status_icon,
                                                          stream);
+                maybe_show_status_icons(applet);
         } else {
                 g_warning ("Unable to get default sink");
         }
@@ -151,6 +170,13 @@ on_control_ready (GvcMixerControl *control,
         update_default_source (applet);
 }
 
+static void
+on_control_connecting (GvcMixerControl *control,
+                       GvcApplet       *applet)
+{
+        g_debug ("Connecting..");
+}
+
 static void
 on_control_default_sink_changed (GvcMixerControl *control,
                                  guint            id,
@@ -195,11 +221,15 @@ gvc_applet_constructor (GType                  type,
 
         self = GVC_APPLET (object);
 
-        self->priv->control = gvc_mixer_control_new ();
+        self->priv->control = gvc_mixer_control_new ("GNOME Volume Control Applet");
         g_signal_connect (self->priv->control,
                           "ready",
                           G_CALLBACK (on_control_ready),
                           self);
+        g_signal_connect (self->priv->control,
+                          "connecting",
+                          G_CALLBACK (on_control_connecting),
+                          self);
         g_signal_connect (self->priv->control,
                           "default-sink-changed",
                           G_CALLBACK (on_control_default_sink_changed),
@@ -243,10 +273,14 @@ gvc_applet_init (GvcApplet *applet)
                                                                        output_icon_names);
         gvc_stream_status_icon_set_display_name (applet->priv->output_status_icon,
                                                  _("Output"));
+        gtk_status_icon_set_title (GTK_STATUS_ICON (applet->priv->output_status_icon),
+                                   _("Sound Output Volume"));
         applet->priv->input_status_icon = gvc_stream_status_icon_new (NULL,
                                                                       input_icon_names);
         gvc_stream_status_icon_set_display_name (applet->priv->input_status_icon,
                                                  _("Input"));
+        gtk_status_icon_set_title (GTK_STATUS_ICON (applet->priv->input_status_icon),
+                                   _("Microphone Volume"));
 }
 
 static void
