@@ -42,6 +42,7 @@
 #include "gvc-mixer-dialog.h"
 #include "gvc-sound-theme-chooser.h"
 #include "gvc-level-bar.h"
+#include "gvc-speaker-test.h"
 
 #define SCALE_SIZE 128
 
@@ -122,7 +123,7 @@ static void     bar_set_stream              (GvcMixerDialog      *dialog,
 static void     on_adjustment_value_changed (GtkAdjustment  *adjustment,
                                              GvcMixerDialog *dialog);
 
-G_DEFINE_TYPE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_VBOX)
 
 static void
 update_default_input (GvcMixerDialog *dialog)
@@ -222,9 +223,9 @@ port_selection_changed (GvcComboBox *combo_box,
 static void
 update_output_settings (GvcMixerDialog *dialog)
 {
-        GvcMixerStream *stream;
-        GvcChannelMap  *map;
-        const GList    *ports;
+        GvcMixerStream      *stream;
+        const GvcChannelMap *map;
+        const GList         *ports;
 
         g_debug ("Updating output settings");
         if (dialog->priv->output_balance_bar != NULL) {
@@ -304,7 +305,7 @@ update_output_settings (GvcMixerDialog *dialog)
 
         ports = gvc_mixer_stream_get_ports (stream);
         if (ports != NULL) {
-                GvcMixerStreamPort *port;
+                const GvcMixerStreamPort *port;
                 port = gvc_mixer_stream_get_port (stream);
 
                 dialog->priv->output_port_combo = gvc_combo_box_new (_("Co_nnector:"));
@@ -599,7 +600,7 @@ update_input_settings (GvcMixerDialog *dialog)
 
         ports = gvc_mixer_stream_get_ports (stream);
         if (ports != NULL) {
-                GvcMixerStreamPort *port;
+                const GvcMixerStreamPort *port;
                 port = gvc_mixer_stream_get_port (stream);
 
                 dialog->priv->input_port_combo = gvc_combo_box_new (_("Co_nnector:"));
@@ -1100,9 +1101,9 @@ add_stream (GvcMixerDialog *dialog,
                                   G_CALLBACK (on_stream_description_notify),
                                   dialog);
         } else if (GVC_IS_MIXER_SINK (stream)) {
-                GtkTreeModel  *model;
-                GtkTreeIter    iter;
-                GvcChannelMap *map;
+                GtkTreeModel        *model;
+                GtkTreeIter          iter;
+                const GvcChannelMap *map;
 
                 model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->priv->output_treeview));
                 gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -1196,7 +1197,7 @@ remove_stream (GvcMixerDialog  *dialog,
                 bar_set_stream (dialog, bar, NULL);
         } else if (bar != NULL) {
                 g_hash_table_remove (dialog->priv->bars, GUINT_TO_POINTER (id));
-                gtk_container_remove (GTK_CONTAINER (bar->parent),
+                gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (bar)),
                                       bar);
                 dialog->priv->num_apps--;
                 if (dialog->priv->num_apps == 0) {
@@ -1266,6 +1267,9 @@ add_card (GvcMixerDialog *dialog,
                 if (gvc_mixer_card_get_index (selected) == gvc_mixer_card_get_index (card)) {
                         gvc_combo_box_set_active (GVC_COMBO_BOX (dialog->priv->hw_profile_combo),
                                                   profile->profile);
+                        g_object_set (G_OBJECT (dialog->priv->hw_profile_combo),
+                                      "show-button", profile->n_sinks == 1,
+                                      NULL);
                 }
         }
 }
@@ -1497,6 +1501,45 @@ on_profile_changed (GvcComboBox *widget,
         gvc_mixer_card_change_profile (card, profile);
 }
 
+static void
+on_test_speakers_clicked (GvcComboBox *widget,
+                          gpointer     user_data)
+{
+        GvcMixerDialog      *dialog = GVC_MIXER_DIALOG (user_data);
+        GvcMixerCard        *card;
+        GvcMixerCardProfile *profile;
+        GtkWidget           *d, *speaker_test, *container;
+        char                *title;
+
+        card = g_object_get_data (G_OBJECT (widget), "card");
+        if (card == NULL) {
+                g_warning ("Could not find card for combobox");
+                return;
+        }
+        profile = gvc_mixer_card_get_profile (card);
+
+        g_debug ("XXX Start speaker testing for profile '%s', card %s XXX",
+                 profile->profile, gvc_mixer_card_get_name (card));
+
+	title = g_strdup_printf (_("Speaker Testing for %s"), gvc_mixer_card_get_name (card));
+	// FIXME
+	// set parent dialogue
+	// https://bugzilla.gnome.org/show_bug.cgi?id=621940
+        d = gtk_dialog_new_with_buttons (title,
+                                         NULL,
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+                                         NULL);
+        g_free (title);
+        speaker_test = gvc_speaker_test_new (dialog->priv->mixer_control,
+                                             card);
+        gtk_widget_show (speaker_test);
+        container = gtk_dialog_get_content_area (GTK_DIALOG (d));
+        gtk_container_add (GTK_CONTAINER (container), speaker_test);
+
+        gtk_dialog_run (GTK_DIALOG (d));
+        gtk_widget_destroy (d);
+}
+
 static void
 on_card_selection_changed (GtkTreeSelection *selection,
                            gpointer          user_data)
@@ -1536,17 +1579,23 @@ on_card_selection_changed (GtkTreeSelection *selection,
         current_profile = gvc_mixer_card_get_profile (card);
         profiles = gvc_mixer_card_get_profiles (card);
         dialog->priv->hw_profile_combo = gvc_combo_box_new (_("_Profile:"));
+        g_object_set (G_OBJECT (dialog->priv->hw_profile_combo), "button-label", _("Test Speakers"), NULL);
         gvc_combo_box_set_profiles (GVC_COMBO_BOX (dialog->priv->hw_profile_combo), profiles);
         gvc_combo_box_set_active (GVC_COMBO_BOX (dialog->priv->hw_profile_combo), current_profile->profile);
 
         gtk_box_pack_start (GTK_BOX (dialog->priv->hw_settings_box),
                             dialog->priv->hw_profile_combo,
                             TRUE, TRUE, 6);
+        g_object_set (G_OBJECT (dialog->priv->hw_profile_combo),
+                      "show-button", current_profile->n_sinks == 1,
+                      NULL);
         gtk_widget_show (dialog->priv->hw_profile_combo);
 
         g_object_set_data (G_OBJECT (dialog->priv->hw_profile_combo), "card", card);
         g_signal_connect (G_OBJECT (dialog->priv->hw_profile_combo), "changed",
                           G_CALLBACK (on_profile_changed), dialog);
+        g_signal_connect (G_OBJECT (dialog->priv->hw_profile_combo), "button-clicked",
+                          G_CALLBACK (on_test_speakers_clicked), dialog);
 }
 
 static void
@@ -1623,32 +1672,6 @@ create_cards_treeview (GvcMixerDialog *dialog,
         return treeview;
 }
 
-static const guint tab_accel_keys[] = {
-        GDK_1, GDK_2, GDK_3, GDK_4
-};
-
-static void
-dialog_accel_cb (GtkAccelGroup    *accelgroup,
-                 GObject          *object,
-                 guint             key,
-                 GdkModifierType   mod,
-                 GvcMixerDialog   *self)
-{
-        gint num = -1;
-        gint i;
-
-        for (i = 0; i < G_N_ELEMENTS (tab_accel_keys); i++) {
-                if (tab_accel_keys[i] == key) {
-                        num = i;
-                        break;
-                }
-        }
-
-        if (num != -1) {
-                gtk_notebook_set_current_page (GTK_NOTEBOOK (self->priv->notebook), num);
-        }
-}
-
 static GObject *
 gvc_mixer_dialog_constructor (GType                  type,
                               guint                  n_construct_properties,
@@ -1668,16 +1691,12 @@ gvc_mixer_dialog_constructor (GType                  type,
         GvcMixerStream   *stream;
         GvcMixerCard     *card;
         GtkTreeSelection *selection;
-        GtkAccelGroup    *accel_group;
-        GClosure         *closure;
-        gint             i;
 
         object = G_OBJECT_CLASS (gvc_mixer_dialog_parent_class)->constructor (type, n_construct_properties, construct_params);
 
         self = GVC_MIXER_DIALOG (object);
-        gtk_dialog_add_button (GTK_DIALOG (self), "gtk-close", GTK_RESPONSE_OK);
 
-        main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
+        main_vbox = GTK_WIDGET (self);
         gtk_box_set_spacing (GTK_BOX (main_vbox), 2);
 
         gtk_container_set_border_width (GTK_CONTAINER (self), 6);
@@ -1702,23 +1721,6 @@ gvc_mixer_dialog_constructor (GType                  type,
                             TRUE, TRUE, 0);
         gtk_container_set_border_width (GTK_CONTAINER (self->priv->notebook), 5);
 
-        /* Set up accels (borrowed from Empathy) */
-        accel_group = gtk_accel_group_new ();
-        gtk_window_add_accel_group (GTK_WINDOW (self), accel_group);
-
-        for (i = 0; i < G_N_ELEMENTS (tab_accel_keys); i++) {
-                closure =  g_cclosure_new (G_CALLBACK (dialog_accel_cb),
-                                           self,
-                                           NULL);
-                gtk_accel_group_connect (accel_group,
-                                         tab_accel_keys[i],
-                                         GDK_MOD1_MASK,
-                                         0,
-                                         closure);
-        }
-
-        g_object_unref (accel_group);
-
         /* Effects page */
         self->priv->sound_effects_box = gtk_vbox_new (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (self->priv->sound_effects_box), 12);
@@ -2041,9 +2043,6 @@ gvc_mixer_dialog_new (GvcMixerControl *control)
 {
         GObject *dialog;
         dialog = g_object_new (GVC_TYPE_MIXER_DIALOG,
-                               "icon-name", "multimedia-volume-control",
-                               "title", _("Sound Preferences"),
-                               "has-separator", FALSE,
                                "mixer-control", control,
                                NULL);
         return GVC_MIXER_DIALOG (dialog);
