@@ -191,7 +191,7 @@ show_missing_known_element_error (GtkWindow *win, gchar *description,
 {
 	show_error_dialog (win, NULL,
             _("Could not create the GStreamer %s element.\n"
-	      "Please install the '%s' plug-in from the '%s' module.\n"
+	      "Please install the '%s' plugin from the '%s' module.\n"
 	      "Verify that the installation is correct by running\n"
               "    gst-inspect-0.10 %s\n"
 	      "and then restart gnome-sound-recorder."),
@@ -207,7 +207,7 @@ show_profile_error (GtkWindow *win, gchar *debug, gchar *description,
 	first = g_strdup_printf (description, profile);
 	show_error_dialog (win, debug, "%s%s", first,
 		  _("Please verify its settings.\n"
-		    "You may be missing the necessary plug-ins."));
+		    "You may be missing the necessary plugins."));
 	g_free (first);
 }
 /* Why do we need this? when a bin changes from READY => NULL state, its
@@ -578,7 +578,7 @@ pipeline_error_cb (GstBus * bus, GstMessage * msg, GSRWindow * window)
 
 	show_error_dialog (GTK_WINDOW (window), dbg, "%s", error->message);
 
-	gdk_window_set_cursor (window->priv->main_vbox->window, NULL);
+	gdk_window_set_cursor (gtk_widget_get_window (window->priv->main_vbox), NULL);
 
 	set_action_sensitive (window, "Stop", FALSE);
 	set_action_sensitive (window, "Play", TRUE);
@@ -614,7 +614,7 @@ gsr_dialog_add_button (GtkDialog *dialog,
 			      gtk_image_new_from_stock (stock_id,
 							GTK_ICON_SIZE_BUTTON));
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
@@ -855,7 +855,7 @@ gsr_discard_confirmation_dialog (GSRWindow *window, gboolean closing)
 	gchar *utf8_filename = NULL;
 	gboolean ret = TRUE;
 
-	confirmation_dialog = gtk_message_dialog_new_with_markup (NULL,
+	confirmation_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
 								  GTK_DIALOG_MODAL,
 								  GTK_MESSAGE_WARNING,
 								  GTK_BUTTONS_NONE,
@@ -1091,7 +1091,7 @@ file_properties_cb (GtkAction *action,
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 	fp = g_new (struct _file_props, 1);
 	fp->dialog = dialog;
 
@@ -1100,7 +1100,7 @@ file_properties_cb (GtkAction *action,
 
 	vbox = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vbox, TRUE, TRUE, 0);
 
 	inner_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, FALSE, FALSE,0);
@@ -1361,7 +1361,7 @@ seek_to (GtkRange *range,
 	if (window->priv->play->state < GST_STATE_PLAYING)
 		return FALSE;
 
-	value = range->adjustment->value;
+	value = gtk_adjustment_get_value (gtk_range_get_adjustment (range));
 	time = ((value / 100.0) * window->priv->len_secs) * GST_SECOND;
 
 	gst_element_seek (window->priv->play->pipeline, 1.0, GST_FORMAT_TIME,
@@ -1427,8 +1427,8 @@ play_tick_callback (GSRWindow *window)
 		pos = (gdouble) (val - (val % GST_SECOND));
 		len = (gdouble) window->priv->len_secs * GST_SECOND;
 		percentage = pos / len * 100.0;
-		
-		gtk_adjustment_set_value (GTK_RANGE (window->priv->scale)->adjustment,
+
+		gtk_adjustment_set_value (gtk_range_get_adjustment (GTK_RANGE (window->priv->scale)),
 		                          CLAMP (percentage + 0.5, 0.0, 100.0));
 	} else {
 		GST_DEBUG ("failed to query position");
@@ -1509,7 +1509,7 @@ play_state_changed_cb (GstBus * bus, GstMessage * msg, GSRWindow * window)
 				   window->priv->status_message_cid);
 		gtk_statusbar_push (GTK_STATUSBAR (window->priv->statusbar),
 				    window->priv->status_message_cid,
-				    _("Playing..."));
+				    _("Playing…"));
 
 		if (window->priv->ebusy_timeout_id) {
 			g_source_remove (window->priv->ebusy_timeout_id);
@@ -1523,7 +1523,7 @@ play_state_changed_cb (GstBus * bus, GstMessage * msg, GSRWindow * window)
 			g_source_remove (window->priv->play->tick_id);
 			window->priv->play->tick_id = 0;
 		}
-		gtk_adjustment_set_value (GTK_RANGE (window->priv->scale)->adjustment, 0.0);
+		gtk_adjustment_set_value (gtk_range_get_adjustment (GTK_RANGE (window->priv->scale)), 0.0);
 		gtk_widget_set_sensitive (window->priv->scale, FALSE);
 		/* fallthrough */
 	case GST_STATE_PAUSED:
@@ -1729,7 +1729,7 @@ record_start (gpointer user_data)
 			   window->priv->status_message_cid);
 	gtk_statusbar_push (GTK_STATUSBAR (window->priv->statusbar),
 			    window->priv->status_message_cid,
-			    _("Recording..."));
+			    _("Recording…"));
 
 	window->priv->record_id = 0;
 
@@ -1778,7 +1778,7 @@ record_state_changed_cb (GstBus *bus, GstMessage *msg, GSRWindow *window)
 		gtk_widget_set_sensitive (window->priv->input, FALSE);
 		break;
 	case GST_STATE_READY:
-		gtk_adjustment_set_value (GTK_RANGE (window->priv->scale)->adjustment, 0.0);
+		gtk_adjustment_set_value (gtk_range_get_adjustment (GTK_RANGE (window->priv->scale)), 0.0);
 		gtk_widget_set_sensitive (window->priv->scale, FALSE);
 		gtk_widget_set_sensitive (window->priv->profile, TRUE);
 		gtk_widget_set_sensitive (window->priv->input, GST_IS_MIXER (window->priv->mixer));
@@ -1830,7 +1830,7 @@ make_record_source (GSRWindow *window)
 		show_error_dialog (NULL, NULL,
 			_("Your audio capture settings are invalid. "
 			  "Please correct them with the \"Sound Preferences\" "
-			  "under the System-Preferences menu."));
+			  "under the System Preferences menu."));
 		return FALSE;
 	}
 	window->priv->source = source;
@@ -2276,7 +2276,7 @@ gsr_window_init (GSRWindow *window)
 	if (error != NULL)
 	{
 		show_error_dialog (GTK_WINDOW (window), error->message,
-			_("Could not load ui.xml. The program may be not properly installed"));
+			_("Could not load UI file. The program may not be properly installed."));
 		g_error_free (error);
 		exit (1);
 	}
@@ -2444,7 +2444,7 @@ gsr_window_init (GSRWindow *window)
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 2, 3,
 			  GTK_FILL, 0, 0, 0);
-	
+
 	priv->length_label = gtk_label_new ("");
 	gtk_label_set_selectable (GTK_LABEL (priv->length_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->length_label), 0, 0.5);
@@ -2459,7 +2459,7 @@ gsr_window_init (GSRWindow *window)
 
 	/* statusbar */
 	priv->statusbar = gtk_statusbar_new ();
-	GTK_WIDGET_SET_FLAGS (priv->statusbar, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (priv->statusbar, TRUE);
 	gtk_box_pack_end (GTK_BOX (main_vbox), priv->statusbar, FALSE, FALSE, 0);
 	gtk_widget_show (priv->statusbar);
 
@@ -2571,7 +2571,7 @@ gsr_window_set_property (GObject      *object,
 		gsr_add_recent (priv->filename);
 
 		/*Translators: this is the window title, %s is the currently open file's name or Untitled*/
-		title = g_strdup_printf (_("%s - Sound Recorder"), utf8_name);
+		title = g_strdup_printf (_("%s — Sound Recorder"), utf8_name);
 		gtk_window_set_title (GTK_WINDOW (window), title);
 		g_free (title);
 		g_free (utf8_name);
